# -*- coding: utf-8 -*-
from setuphelpers import *

r"""
['PsExec', 'psfile', 'PsGetsid', 'PsInfo', 'pskill', 'pslist', 'PsLoggedon', 'psloglist', 'pspasswd', 'psping', 'PsService', 'psshutdown', 'pssuspend']

    # Accepting EULA
    tools_list = []
    for tool in glob.glob(makepath(app_dir, '*.exe')):
        tool_name = tool.split('\\')[-1].split('.exe')[0]
        if not '64' in tool_name:
            tools_list.append(tool_name)

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
bin_contains = "PSTools"
app_name = "PSTools"
app_dir = makepath(programfiles32, app_name)
tools_list = [
    "PsExec",
    "psfile",
    "PsGetsid",
    "PsInfo",
    "pskill",
    "pslist",
    "PsLoggedon",
    "psloglist",
    "pspasswd",
    "psping",
    "PsService",
    "psshutdown",
    "pssuspend",
]


def install():
    # Declaring local variables
    package_version = control.get_software_version()
    bin_name = glob.glob("*%s*.zip" % bin_contains)[0]

    # Getting installed software version
    if isdir(app_dir):
        installed_version = installed_softwares(app_name)[0]["version"]
    else:
        installed_version = None

    # Installing software
    print("Installing: %s" % app_name)
    if installed_version is None or Version(installed_version) < Version(package_version) or force:
        killalltasks(control.get_impacted_process_list())
        if isdir(app_dir):
            remove_tree(app_dir)
        mkdirs(app_dir)
        print("Extracting: %s to: %s" % (bin_name, app_dir))
        unzip(bin_name, app_dir)

        # Adding software to "list-registry"
        register_windows_uninstall(control, win64app=False)
    else:
        print("%s (%s) already installed. Skipping" % (app_name, package_version))

    # Adding folder to PATH
    add_to_system_path(app_dir)

    # Accepting EULA
    print("Accepting: %s EULA" % app_name)
    for tool_name in tools_list:
        for sid in [".DEFAULT", "S-1-5-18", "S-1-5-19", "S-1-5-20"]:
            if not reg_value_exists(HKEY_USERS, r"%s\SOFTWARE\Sysinternals\%s" % (sid, tool_name), "EulaAccepted"):
                registry_set(HKEY_USERS, r"%s\SOFTWARE\Sysinternals\%s" % (sid, tool_name), "EulaAccepted", 1)


def session_setup():
    print("Accepting: %s EULA" % app_name)
    for tool_name in tools_list:
        if not reg_value_exists(HKEY_CURRENT_USER, r"SOFTWARE\Sysinternals\%s" % tool_name, "EulaAccepted"):
            registry_set(HKEY_CURRENT_USER, r"SOFTWARE\Sysinternals\%s" % tool_name, "EulaAccepted", 1)


def uninstall():
    # Uninstalling software
    killalltasks(control.get_impacted_process_list())
    if isdir(app_dir):
        remove_tree(app_dir)
    unregister_uninstall(app_name)

    # Removing folder from PATH
    remove_from_system_path(app_dir)

    print("Removing: %s EULA consent" % app_name)
    for tool_name in tools_list:
        for sid in [".DEFAULT", "S-1-5-18", "S-1-5-19", "S-1-5-20"]:
            if reg_key_exists(HKEY_USERS, r"%s\SOFTWARE\Sysinternals\%s" % (sid, tool_name)):
                registry_deletekey(HKEY_USERS, r"%s\SOFTWARE\Sysinternals" % (sid), tool_name)


def audit():
    # Auditing software
    print("Auditing: %s" % control.package)
    if isdir(app_dir):
        print("%s present" % app_dir)
        return "OK"
    else:
        print("%s absent" % app_dir)
        return "ERROR"
